<!--
SPDX-FileCopyrightText: 2023 Curious Community Labs e. V. <akustik-absorber@curious.bio>

SPDX-License-Identifier: CC-BY-SA-4.0
-->

# Abschlussbericht

Wie gut lassen sich Akustikabsorber-Prototypen aus Pilzmyzelmaterialien in einem
Fablab mit der Unterstützung digitaler Werkzeuge reproduzieren?

1. [Einleitung](#1-einleitung)
2. [Dokumentation](#2-dokumentation)
3. [Vorbereitung](#3-vorbereitung)  
    1. [Auswahl digitaler Werkzeuge](#31-auswahl-digitaler-werkzeuge)  
        1. [3D-Drucker](#3-1-1-3d-drucker)  
        2. [Lasercutter](#3-1-2-lasercutter)  
        3. [CNC-Fräse](#3-1-3-cnc-fräse)  
        4. [FreeCAD](#3-1-4-freecad)  
    2. [Hardwarenutzung in offenen Laboren in Hamburg](#3-2-hardwarenutzung-in-offenen-laboren-in-hamburg)  
        1. [Curious Community Labs e. V. (CCL)](#3-2-1-curious-community-labs-e-v-ccl)  
        2. [Openlab Hamburg](#3-2-2-openlab-hamburg)  
        3. [Fabulous St. Pauli e. V.](#3-2-3-fabulous-st-pauli-e-v)  
4. [Workshopdurchführung](#4-workshopdurchführung)  
    1. [Workshop Tag 1](#4-1-workshop-tag-1)  
        1. [Reproduzierbarkeit](#4-2-1-reproduzierbarkeit)  
        2. [Nachbereitung](#4-1-2-nachbereitung)  
    2. [Workshop Tag 2](#4-2-workshop-tag-2)  
        1. [Reproduzierbarkeit](#4-2-1-reproduzierbarkeit)  
        2. [Nachbereitung](#4-2-2-nachbereitung)  
    3. [Workshop Tag 3](#4-3-workshop-tag-3)  
        1. [Reproduzierbarkeit](#4-3-1-reproduzierbarkeit)  
        2. [Nachbereitung](#4-3-2-nachbereitung)  
5. [Hürden und Probleme](#5-hürden-und-probleme)  
6. [Fazit](#6-fazit)  



## 1. Einleitung

Die Forschungsfrage, die Eingangs genannt wird, beschäftigt sich mit der
Reproduzierbarkeit von Akustikabsorber-Prototypen aus Pilzmyzelmaterialien, die
in einem FabLab-Kontext mit der Unterstützung digitaler Werkzeuge hergestellt
werden.
Im Rahmen des FabCity Interfacer-Projektes wurden dazu zwei Workshopreihen
durchgeführt und insgesamt 24 Prototypen hergestellt, woraus Erkenntnisse über
den Herstellungsprozess sowie die Reproduzierbarkeit abgeleitet werden können.
Weiteres Ziel dieser Arbeit ist es, einen Beitrag zur lokalen, kreiswirtschaftlichen
Produktion zu leisten und alle zur Reproduktion notwendigen Daten unter Open
Source Lizenz bereitzustellen.
Dieser Bericht stellt die Erkenntnisse und Erfahrungen dar, um aus der
Workshopreihe lernen zu können und um einen nachhaltigen Beitrag für zukünftige
Workshopreihen zu leisten. Der Erkenntnisstand soll über die Dokumentation sowie
über die Vorbereitung, Durchführung und Nachbereitung der Workshops dargelegt
werden.

## 2. Dokumentation

Die Dokumentation wurde von uns über Gitea als remote server und lokalen Git
Instanzen erstellt. Die FabCity bietete dabei Beispiele für den Aufbau eines
Repository sowie Rahmenbedingungen für eine Open Source gerechten
Veröffentlichung. Die zugrunde liegende Norm ist die DIN SPEC 3105.
Die Arbeitsweise mit der Dokumentation hat sich als sehr nützlich erwiesen, da
dadurch sowohl die Projektplanung gemacht werden konnte als auch die
Dokumentation versionsweise optimiert werden konnte. Der Herstellungsprozess
konnte und kann somit kontinuierlich verbessert werden.
Es wurden im Repository auf standardisierte Ordnerstrukturen Wert gelegt, um eine
Vergleichbarkeit mit anderen Repositories zu ermöglichen. Alle Texte wurden im
Markdown-Format geschrieben, um eine Verbesserung leicht durchführbar zu
machen. Bei den Software Tools wurde, soweit es ging frei verfügbare Software
benutzt wie z.B. FreeCAD und Inkscape. Es wurde aber ebenfalls für das
Absorberdesign eine gekaufte Software, Rhino3D, genutzt, da für das Erstellen
eines komplexen Designs keine vergleichbare Open Source Software vorhanden
war.
Die bill of materials ist in einer CSV datei gespeichert, die eine leichte Anpassung
ermöglicht.
Bei der Lizenzauswahl wurde mit ähnlichen Veröffentlichungen im Bereich
Myzelmaterialien verglichen und CC-BY-SA-4.0 als passende Lizenz ausgewählt.

## 3. Vorbereitung

Bei der Vorbereitung für die Workshops wurde ein Zeitplan erstellt. Da das
Pilzmyzel, sobald es einmal wächst, direkt weiterverarbeitet werden muss, ist ein
methodisches und vorrausschauendes Arbeiten notwendig. Die Vorbereitung der
nicht lebendigen Bestandteile (Wachstumsformen und Befestigung) wurde als
erstes geplant und zum größten Teil vor der Arbeit mit dem Pilzmyzel bereits
durchgeführt.
Insgesamt war der Vorbereitungsaufwand für einen reibungslosen Workshopablauf
im Vergleich zur Workshopdurchführung relativ hoch. Es wurden Holzteile
gefertigt, die Wachstumsformen eingekauft und bearbeitet sowie sämtliche
Hygiene- und Verbrauchsartikel organisiert und Pilzmyzel bestellt.
Bei den Vorbereitungsschritten mit 3D-Drucker und Lasercutter haben wir
festgestellt, dass genügend Zeit eingeplant werden muss, um die Ergebnisse im
Vorfeld beurteilen zu können und eventuelle Anpassungen vorzunehmen.
Die Materialien, die in der bill of materials dargestellt sind, bezogen wir
weitgehend aus dem Baumarkt. Bei höheren Stückzahlen waren in der Filiale nicht
immer genügend Materialien vorhanden und es musste zum Teil online bestellt
werden.

### 3.1. Auswahl digitaler Werkzeuge

#### 3.1.1. 3D-Drucker

Das Design der Prototypen ließ sich durch unterschiedliche computergestützte 3D-
Modellierung umsetzen. Die Formgebung stellte die Rahmenbedingungen für die

Herstellungsmethode der Wachstumsform. Sie berücksichtigte die Entformbarkeit
des Myzelmaterials, Handling während des Herstellungsprozesses sowie das
spätere Gesamtbild nach Installation an der Wand.
Ziel bei der Auswahl war es, eine Nachbearbeitung der Paneele nach der
Durchwachsung durch eine gut gestaltete Wachstumsform so gering wie möglich zu
halten. Die Wahl der Methode zur Herstellung der Wachstumsformen fiel auf den
3D-Druck.
Der Vorteil eines 3D Druckes liegt in der Möglichkeit, sehr gleichmäßge und sich
wiederholende Strukturen herzustellen. Durch die Wahl eines 2-Teiligen Aufbaus
der Wachstumsform mit Hilfe einer Aufbewahrungsbox aus Kunststoff und einer
3D-gedruckten Designform als Negativ-Einsatz konnten wir sämtliche
Oberflächengestaltungen, welche vorher virtuell designt wurden, abbilden. Durch
die Bereitstellung der .stl Dateien ist eine Designänderung individuell anpassbar
und ein erneuter Ausdruck möglich.

#### 3.1.2. Lasercutter

Da Pilzmyzel ein lebendiges, dynamisch wachsendes Material ist, besteht sowohl in
der Phase der Durchwachsung als auch bei späterer Trocknung die Möglichkeit,
dass sich angestrebte Dimensionen nicht einhalten lassen.
Für den von uns gewählten Herstellungsprozess war eine exakte Positionierung der
Befestigungsanker entscheidend. Um eine genau reproduzierbare Anordnung der
Verankerung zu gewährleisten, bot sich die Bearbeitung der Wachstumsform mit
einem Lasercutter an.
In den Deckeln der Aufbewahrungsboxen (Wachstumsform) wurden an genau
festgelegten Positionen quadratische Aussparungen geschnitten. Der Laser lässt
sich mittels einer Vektorgrafik im .svg Format steuern. Dadurch ließen sich die
Kunststoffdeckel leicht reproduzierbar und sehr genau bearbeiten.

#### 3.1.3. CNC-Fräse

Für das Befestigungssystem wurden Nutleisten benötigt.
Die im Baumarkt verfügbaren Formate von Nutleisten waren für unsere Anwendung
nicht geeignet. Um eine Nut nach unseren Maßen herzustellen, wurden
Rechteckleisten mit Hilfe einer CNC-Fräse mit einer Nut versetzt.
Auf dem Fräsbett wurde dazu eine Haltevorrichtung für die Leisten angebracht.
Nach Einstellen des Fräskopfes konnte in kurzer Zeit eine hohe Stückzahl an Leisten
bearbeitet werden. Die Fräsungen hatten eine hohe Genauigkeit und waren gut
reproduzierbar.

#### 3.1.4. FreeCAD

FreeCAD ist ein Open Source CAD Programm, welches wir für die Erstellung der
technischen Zeichnungen der Holzwerkstücke (Anker und Befestigungssystem)
genutzt haben. Das Programm bot ausreichende Möglichkeiten, um die technischen
Zeichnungen zu erstellen. Dadurch, dass FreeCAD Open Source ist, ist eine
Adaption des Befestigungssystems oder der Holzanker durch weitere Anwender
leicht möglich.

### 3.2. Hardwarenutzung in offenen Laboren in Hamburg

#### 3.2.1. Curious Community Labs e. V. (CCL)

Beim Herstellungsprozess der Pilzmyzelmaterialien werden spezielle Labor-
Werkzeuge benötigt. Diese sind entweder sehr groß oder sehr teuer, so dass sich

Privatpersonen diese normalerweise nicht kaufen. Im offenen Gemeinschafts-
Biolabor (CCL) können Gerätschaften für biologische Anwendungen genutzt werden.

Zwei der drei Workshoptage wurden in den Räumlichkeiten des CCL durchgeführt.
Für die Workshopdurchführung benötigten wir:
• Kühlschrank
• Autoklav mit sterilisierbaren Beuteln
• Laminarströmungsabzug
• Impulsschweißgerät
• temperaturkontrolliertes Wachstumszelt
• PSA (Handschuhe, Mundschutz)
• Desinfektionsmittel

#### 3.2.2. Openlab Hamburg

Das Openlab Hamburg befindet sich auf dem Gelände der Helmut-Schmidt-
Universität und bietet der Öffentlichkeit einen Zugang zu modernen, digitalen

Fabrikationstechnologien.
Im Openlab wurden wir vom Labormanager tatkräftig unterstützt. Es konnte auf
folgende 3D Drucker zurückgegriffen werden:
• BigRep One 1.3
• Ultimaker 2 extended
Bei dem BigRep One 1.3 handelt es sich um einen großen 3D Drucker, der für den
Druck der einteiligen Positiv- und Negativformen zum Einsatz kam. Der BigRep ist
wegen seiner Größe und Anschaffungskosten häufig nicht in offenen Laboren
vorhanden. Daher wurden ebenfalls mehrteilige Positiv- und Negativformen
entworfen, die in unserem Fall mit einem Ultimaker 2 extended gedruckt wurden.
Die mehrteiligen Positiv- und Negativformen lassen sich auch mit gewöhnlichen
3D-Druckern drucken, die in offenen Laboren häufiger anzutreffen sind. Die
Reproduzierbarkeit der Wachstumsformen ist durch die Genauigkeit und
Fehlerabweichung des jeweilig genutzten 3D Druckers festgelegt.

#### 3.2.3. Fabulous St. Pauli e. V.

Das FabLab Fabulous St. Pauli befindet sich in direkter Nachbarschaft zum CCL.
Ähnlich wie im offenen Biolabor können hier große Maschinen gemeinschaftlich
genutzt werden.
Für die Workshopvorbereitung verwendeten wir den Lasercutter Epilog Zing 24.
Dieser leistungsstarke Lasercutter mit einem Druckbett von 30x60 cm war
geeignet, die dünnwandigen Deckel der Aufbewahrungsbox bestehend aus
Polypropylen zu schneiden.
Auch Hilfsmittel für den Herstellungsprozess, wie Positionierungslehren oder
Druckplatten konnten mit dem Lasercutter sehr exakt gefertigt werden.
Außerdem verwendeten wir für Holzteile die große CNC-Fräse, welche ebenfalls im
FabLab genutzt werden kann.


## 4. Workshopdurchführung

Die Workshopdurchführung lief, dank viel Vor- und Nachbereitung und großzügiger
Zeitplanung für den Workshoptag selbst, zeitlich entspannt ab. Hilfsmittel wurden
im Vorfeld hergestellt und Materialien bereitgestellt.

### 4.1. Workshop Tag 1

Nach Begrüßung und Orientierung folgten Infos zum Projekt und eine Erläuterung
des Tagesablaufs.
Die Arbeitsschritte wurden in 2 Teile gegliedert, sodass vormittags das Vorbereiten
und Sterilisieren des Substrats und nachmittags das Beimpfen des Substrats mit der
Pilzkultur vorgenommen wurde.
Die Teilnehmer:innen erlernten an einem Tag alles, was theoretisch und praktisch
benötigt wird, um das Pilzmyzel für die Durchwachsungsphase vorzubereiten.
Es wurde darauf Wert gelegt, die praktischen Fähigkeiten mehrmals zu
wiederholen, um sie gut zu verinnerlichen. Die Teilnehmer:innen meldeten zurück,
dass auch die vermittelten Inhalte überschaubar und verständlich waren.
Als Nadelöhr für den Ablauf stellte sich die sterile Werkbank heraus, da dort immer
maximal eine Person arbeiten und eine weitere zuarbeiten kann. Die
Workshopteilnehmer:innen empfanden dies nicht als störend, da sie dadurch genug
Freiraum hatten, um zu beobachten, Gelerntes zu integrieren oder sich
auszutauschen und kennenzulernen.

#### 4.1.1. Reproduzierbarkeit

Insgesamt wurden pro Workshop 12 Substratbeutel hergestellt und beimpft. Bei 6
Teilnehmer:innen konnte so jede Person 2 Beutel bearbeiten. Durch genaues
Anleiten konnten vergleichbare Ergebnisse erzielt werden. Besonders beim sterilen
Arbeiten wurde sogfältig angeleitet. Die Inhalte waren auch für Anfänger
verständlich und die Arbeitsschritte für alle gut durchführbar.

#### 4.1.2. Nachbereitung

Die von den Workshopteilnehmer:innen hergestellten 12 Substratbeutel wurden
gegen Ende des Workshops sterilisiert. Nachdem sie über Nacht ausgekühlt waren,
wurden sie am Folgetag von den Workshopdurchführenden mit der Pilzkultur
beimpft und anschließend in ein Wachstumszelt gegeben.

### 4.2. Workshop Tag 2

Am zweiten Workshoptag wurde das beimpfte Substrat in die Akustikabsorberform
überführt. Dieser Ablauf war deutlich komplexer und enthielt viele Einzelschritte.
Für 12 Prototypen ergab sich bei einer durchschnittlichen Bearbeitungszeit von 30
Minuten pro Paneel eine praktische Arbeitsphase von insgesamt 6 Stunden. Nach
dem Check-in und Vorstellen der Aufgaben für den Tag, wurde relativ zügig mit
dem praktischen Teil begonnen. Mit Pausen und einem Zeitpuffer für das
abschließende Aufräumen konnte die Workshopdauer von 8 Stunden eingehalten
werden.
Um möglichst einheitliche Prototypen herzustellen, wurden von den
Workshopdurchführenden immer wieder genaue Hinweise gegeben.
Auch am Workshop Tag 2 stellte sich die sterile Werkbank als limitierender Faktor
heraus. Praktischerweise konnten die anderen Teilnehmer:innen zuarbeiten oder
zuschauen, um so den Ablauf mehrmals zu sehen und zu lernen, bevor sie selbst an
der Reihe waren.

#### 4.2.1. Reproduzierbarkeit

Insgesamt wurden pro Workshop 12 Prototypen hergestellt. Bei 6 Teilnehmer:innen
konnte so jede Person 2 Prototypen herstellen. Durch den ersten Workshoptag
hatten die Teilnehmer:innen bereits Vorkenntnisse und somit keine
Schwierigkeiten, die vermittelten Inhalte und Arbeitsschritte zu verstehen und
durchzuführen. Die Ergebnisse waren einheitlich.

#### 4.2.2. Nachbereitung

Die Nachbereitung des zweiten Workshoptages erforderte Arbeiten an drei
zusätzlichen Tagen bevor der letzte Workshop beginnen konnte.
Die Prototypen wurden nach dem Workshoptag in das Wachstumszelt gebracht und
fünf Tage wachsen gelassen.
Ohne die Workshopteilnehmer:innen wurde darauf folgend aus allen
Wachstumsformen die Negativ-Form entfernt. Dieser Schritt hat zu dritt ca. 3
Stunden in Anspruch genommen.
Nach weiteren vier Tagen Wachstum wurden die Paneele getrocknet. Das
Entformen und die Beschickung des Trockners hat zu zweit ca. 1 Stunde gedauert.
Nach dem Trocknen wurden die Absorber vermessen und die Bohrlehren für die
Löcher und Muffen in der Verankerung erstellt. Ein Teil der Absorber wurde vorab
vorbereitet, sodass die Arbeitszeit am letzten Workshoptag ausreichte, um alle
Absorber finalisieren zu können. Hierfür wurde ein Tag zu zweit benötigt.

### 4.3. Workshop Tag 3

Am dritten Workshoptag wurden die getrockneten Absorber für die Befestigung
bearbeitet, das Befestigungssystem aufgebaut und die Absorber über das
Befestigungssystem an der Wand installiert.
Die Teilnehmer:innen lernten die Holzbearbeitung der Verankerung und der
Befestigungsleiter kennen. Es wurde hierbei handwerklich an den Verankerungen
der Absorber mithilfe Bohrlehren und Akkuschraubern gearbeitet sowie die
Befestigungsleiter aufgebaut.
Bei der Herstellung der Befestigungsleiter kam es häufiger vor, dass die Schrauben
das Holz spalteten. Es wurde von den Teilnehmer:innen vorgeschlagen, das nächste
mal eine andere Holzdicke zu wählen oder die Schraublöcher vorzubohren.
Die Teilnehmer:innen sahen zum ersten Mal die Ergebnisse des zweiten
Workshoptags. Das Myzel, welches als loses Substrat in Erinnerung war, hatte nun
Form angenommen und war zu einem festen Block zusammengewachsen. Nach
anschließender Anbringung an der Wand konnte eine zusammenhängende Fläche
aus der Ferne betrachtet werden. Die Workshopteilnehmer:innen berichteten, dass
dieser Moment ein eindrückliches Erlebnis war. Die Ergebnisse der vor 3 Wochen
begonnenen Arbeitsschritte waren nun sichtbar.

#### 4.3.1. Reproduzierbarkeit

Pro Workshop wurden insgesamt 4 Befestigungsleitern händisch zusammengesetzt.
Hierbei ist uns aufgefallen, dass die Holzarbeiten vergleichsweise aufwändig sind.
Trotz der Holzlehren für die Löcher in der Verankerung waren die Ankerschrauben
nicht immer parallel zu der Vorderkante der Absorber, sodass es bei der
Aufhängung zu geringen Unterschieden kam.

#### 4.3.2 Nachbereitung

Die Absorber, welche an die Befestigungsleiter angehängt waren, konnten durch
die Stellschrauben in der Verankerung justiert werden, sodass die Ausrichtung der
Kanten parallel zu der Befestigungsleiter war.
Nach Finalisierung der beiden Workshopreihen wurden die Absorber vorbereitet,
um sie in das Akustiklabor der HAW Hamburg zu transportieren. Dort wurden sie
akustisch vermessen. Die ermittelten Absorptionswerte sind vergleichbar mit
herkömmlichen Akustikabsorber Produkten.

## 5. Hürden und Probleme

- Dokumentation:
Das System von Git, Gitlab und Gitea erforderte ein hohes Maß an
Einarbeitung. So musste die Funktionsweise vollständig begriffen werden,
um die Einrichtung vorzunehmen. Es kam immer wieder zu Problemen in der
Verbindung vom local client zum remote server sowie Mergekonflikten.
- Vorbereitung:
Materialbestellungen und Herstellung der Wachstumsformen waren zeitlich
sehr knapp geplant.
Die Wachstumsformen waren durch unterschiedliche Systeme hergestellt
worden. Dadurch kam es zu Abweichungen in der Formgebung und dem
resultierenden Erscheinungsbild der fertigen Absorber.
- Durchführung der Workshops:
Es kam an den ersten beiden Workshoptagen zu Engstellen, da an der
sterilen Werkbank nur eine Teilnehmer:in zur Zeit arbeiten konnte. Die
anderen Teilnehmer:innen konnten aber die Zeit nutzen, um sich Techniken
abzuschauen und Zuarbeiten zu verrichten.
Die Lagerkapazität für die benötigte Menge an Myzelmaterialien reichte im
CCL nicht ganz aus, sodass während der Durchwachsung und Trocknung
örtlich ausgewichen werden musste. Hierbei konnten Räumlichkeiten von
MycoLutions genutzt werden.

## 6. Fazit

Die Workshops haben gezeigt, dass die Herstellung von Myzelmaterialien am
Beispiel von Akustikabsorber-Prototypen in offenen Laboren, wie sie in Hamburg
vorzufinden sind, möglich ist und sich die Prototypen mit den vorhandenen
Maschinen gut reproduzieren lassen.
Die Möglichkeit der Optimierung und Weiterentwicklung ist über Gitea und Gitlab
Open Source gegeben. Das System erfordert zwar ein hohes Maß an Einarbeitung,
die Möglichkeit einer gleichzeitigen Projektsteuerung ist aber lohnenswert.
Die digitalen Werkzeuge 3D Drucker, Lasercutter und CNC Fräse bevorteilen ein
exaktes Arbeiten und die Reproduzierbarkeit.
Für eine größere Anzahl an Absorbern muss räumlich geschaut werden, wo für die
Durchwachsung Platz ist.
Bei hohem Bedarf an Materialien muss rechtzeitig die entsprechende
Materialbestellung angestoßen werden. Eine Methodische Arbeitsweise ist
notwendig, da das Wachstum des Pilzes nicht mehr zu stoppen ist, wenn er auf das
Substrat gebracht wird.
Eine einheitliche Optik lässt sich nur mit gleichartigen Wachstumsformen und
einheitlicher Arbeitsweise schaffen.

## 7. Lizenz

CC-BY-SA-4.0