<!--
SPDX-FileCopyrightText: 2023 Curious Community Labs e. V. <akustik-absorber@curious.bio>

SPDX-License-Identifier: CC-BY-SA-4.0
-->

# README `mod/material_fabrication/`

## Schematische Darstellung des Herstellungsprozesses

![Herstellungsprozess](res/assets/media/img/material_fabrication_flowchart.webp)

## Gliederung

1. [Einleitung](#1-einleitung)
2. [Benötigte Materialien](#2-benötigte-materialien)
3. [Benötigte Werkzeuge](#3-benötigte-werkzeuge)
4. [Substratherstellung](#4-substratherstellung)
    1. [Berechnung der Ausgangsgrößen für die Substratherstellung](#4-1-berechnung-der-ausgangsgrößen-für-die-substratherstellung)
        1. [Bestimmen des benötigten Gesamtvolumens und der Gesamtmasse](#4-1-1-bestimmen-des-benötigten-gesamtvolumens-und-der-gesamtmasse)
        2. [Bestimmen der zu wiegenden Substratmasse und Wassermenge](#4-1-2-bestimmen-der-zu-wiegenden-substratmasse-und-wassermenge)
    2. [Anmischen des Substrats](#4-2-anmischen-des-substrats)
    3. [Sterilisation im Autoklav](#4-3-sterilisation-im-autoklav)
    4. [Beimpfung des Substrats](#4-4-beimpfung-des-substrats)
    5. [Substratdurchwachsung](#4-5-substratdurchwachsung)
    6. [Zerkleinern](#4-6-zerkleinern)
5. [Absorberherstellung](#5-absorberherstellung)
    1. [Befüllung der Form](#5-1-befüllung-der-form)
    2. [Formdurchwachsung](#5-2-formdurchwachsung)
    3. [Anlockern](#5-3-anlockern)
    4. [Entformen](#5-4-entformen)
    5. [Trocknung](#5-5-trocknung)
6. [Sicherheitshinweise](#6-sicherheitshinweise)
7. [Lizenz](#7-lizenz)

## 1. Einleitung

Die Herstellung eines Myzel-Kompositmaterials läuft in mehreren Teilschritten ab und wird folgend genauer beschrieben. Grundsätzlich teilt sie sich in [Substratherstellung](#4-substratherstellung) und [Absorberherstellung](#5-absorberherstellung) auf.

Details hierzu werden aus dem Buch "Mind the fungi" (Meyer, V. (2020). Seite 27-29) entnommen. Zudem lassen sich im Buch "Radical Mycology" (McCoy, P. 2016) sowie in zahlreichen öffentlich einsehbaren wissenschaftlichen Arbeiten Anleitungen zur Herstellung von Myzel-Komposit-Materialien finden.

>Der Herstellungsprozess ist patentrechtlich geschützt. Für eine kommerzielle Anwendung ist die Patentlage eingehend zu prüfen, um eine Patentverletzung zu vermeiden.

Beim Herstellungsprozess wird innerhalb einer Woche zuerst das Substrat in Beuteln mit Myzel durchwachsen. Danach wird eine [Negativform](../mould/README.md) mit dem vorkultiviertem Substrat befüllt und hölzerne [Befestigungsanker](../anchor/README.md) in Position gebracht. In den nächsten 4-6 Tagen wächst das Pilzmyzel weiter und verfestigt das Substrat. Zwischenzeitlich wird es aus der Form entnommen. Die vom Myzel durchwachsenen und umschlossenen Holzanker sind fest mit dem Myzelblock verbunden. Nach der Durchwachsung wird der Pilz abgetötet, in dem das Material für 48 Stunden auf über 55 °C erhitzt und getrocknet wird. Ein Weiterwachsen des Pilzes ist nach diesem Schritt ausgeschlossen.

---
## 2. Benötigte Materialien

- Rapsstroh
- Buchweizenschalen
- Autoklavbeutel
- Wasser
- Körnerbrut der Reishi-Kultur
- Wachstumsform

---
## 3. Benötigte Werkzeuge

- Substratwaage
- Messbecher
- Substratmischer
- Autoklav
- Laminarströmungsabzug
- Impulsschweißgerät
- Hechsler für Substrat
- temperaturkontrolliertes Wachstumszelt

---
## 4. Substratherstellung

Für die Substratmischung wird die hinzuzufügende Wassermenge auf Grundlage der Ausgangsfeuchte der einzelnen Substratbestandteile berechnet. Da unterschiedliche Substrate verschiedene Wasserhaltekapazitäten besitzen, wird die hinzuzufügende Menge Wasser immer vor Ort und auf Grundlage der aktuellen Restfeuchte der Substrate bestimmt.

### 4.1. Berechnung der Ausgangsgrößen für die Substratherstellung

#### 4.1.1. Bestimmen des benötigten Gesamtvolumens und der Gesamtmasse

| Ausgangsgrößen: |  |
| ---: | :--- |
| Substratvolumen/Absorberpaneel | 10 L |
| Anzahl der herzustellendenen Absorber | 12 |
| Mischungsverhältnis Buchweizenschalen/Rapstroh (m/m) | 50/50 |
| Dichte des lockeren und mit Wasser gesättigtem Buchweizenschalen-Rapsstroh-Gemischs: | 275 g/L |
| Substratdichte wassergesättigt und leicht komprimiert: | 320 g/L |
| Gewichtskapazität der Autoklavbeutel: | 1,6 Kg |
| Wasserspeicherkapazität Rapsstroh | 75 % |
| Lagerfeuchtigkeit Rapsstroh (lokal gemessen) | 15 % |
| Wasserspeicherkapazität Buchweizenschalen | 59 % |
| Lagerfeuchtigkeit Buchweizenschalen (lokal gemessen) | 11,7 % |

**Rechnung:**

Pro Paneel wird ein wassergesättigtes leicht komprimiertes Substrat mit der Masse 10 l x 320 g/l = 3200 g benötigt.

Es werden aufgrund der Gewichtskapazität der Autoklavbeutel 2 Autoklavbeutel mit vorkultiviertes Substrat für 1 Paneel verwendet.

Für 12 Absorber werden 3.200 g x 12 = 38,4 Kg fertig gemischtes Substrat benötigt.

#### 4.1.2. Bestimmen der zu wiegenden Substratmasse und Wassermenge

Die Masse von 12 Absorbern wird unter Berücksichtigung des Mischungsverhältnisses zunächst auf die jeweiligen Trockenmassen heruntergerechnet. Danach wird die zu wiegende Substratmasse unter Berücksichtigung ihrer spezifischen Lagerfeuchte berechnet.

**Rechnung:**

38,4 Kg / 2 = 19,2 Kg je Substrat <br>
<br>
**Buchweizenschalen:** <br>

Wasserspeicherkapazität: 59% <br>

19.200 g Buchweizenschalen feucht * 0,41 <br>
= 7.872 g Buchweizenschalen Trockenmasse (0% Feuchtigkeit) <br>
7872 g * 1,117 = 8793 g Buchweizenschalen gelagert (11,7% Feuchtigkeit) <br>
<br>
**Rapsstroh:** <br>

Wasserspeicherkapazität Rapsstroh: 75% <br>

19.200 g Rapsstroh feucht * 0,25 <br>
= 4800 g Rapsstroh Trockenmasse (0% Feuchtigkeit) <br>
4800 g * 1,15 = 5520 g Rapsstroh gelagert (15% Feuchtigkeit) <br>
<br>
Der Gesamtbedarf an Wasser ergibt:<br>
38,4 kg - 8,793 kg - 5,520 kg = 24,1 l<br>

### 4.2. Anmischen des Substrats

Die bestimmten Substrat- und Wassermengen werden in einem Substratmischer oder ggf. manuell vermischt. Das Gemisch sollte mindestens 30 min homogenisiert und hydriert werden. Heißes Wasser beschleunigt den Hydrierungsprozess.

### 4.3. Sterilisation im Autoklav

Die anschließende Sterilisation des Substrats im Autoklav erfolgt nach diesen Schritten:

1. Abfüllen des Substrates in Autoklavbeutel (a 1,6 Kg)
2. Komprimierung und doppeltes Falten der offenen Beutel (Pasteursche Schleife)
3. Befüllen der Korbeinsätze des Autoklavs mit Faltöffnung nach innen zeigend
4. Starten des Autoklaviervorgangs (121 °C, 15 psi, 90 Minuten)
5. Abkühlen über Nacht, Substrat muss vor Beimpfen eine Kerntemperatur von unter 30 °C haben

### 4.4. Beimpfung des Substrats

Sobald die Kerntemperatur des Substrats unter 30 °C liegt, kann dieses mit einer Pilzkultur beimpft werden. Diese Methode verwendet Reishi, auch glänzender Lackporling (Ganoderma lucidum) genannt.

Jeder Substratbeutel mit einem Gewicht von 1600 g wird mit 80 g Pilz-Körnerbrut beimpft. Hierzu wird die Pilzbrut unter sterilen Bedingungen im Laminarströmungsabzug in die Substratbeutel gekippt. Es ist darauf zu achten, dass das Innere der Substratbeutel nicht berührt wird. Anschließend werden die Beutel mit dem Impulsschweißgerät versiegelt und geschüttelt, bis sich die Pilzbrutkörner gleichmäßig im Substrat verteilt haben. Insgesamt wiegt ein Beutel nun 1680 g. Anschließend wird das Substrat in die Inkubation gegeben.

### 4.5. Substratdurchwachsung

Die Durchwachsung (Inkubation) findet bei 24°C und Dunkelheit in einem Wachstumszelt statt.

Ist das Substrat zu mehr als 90% durchwachsen, kann es weiterverarbeitet werden. Die Durchwachsung nimmt ca. 1 Woche in Anspruch.

<img title="Durchwachsene Substratbeutel" src="res/assets/media/img/substrate_pregrown.webp" width="50%">

### 4.6. Zerkleinern

Um eine optimale Abformung der Negativform im späteren Prozess zu erreichen, muss das Myzel nach der Vorkultivierung wieder zerkleinert werden.

Dies wird mit einem herkömmlichen Grünguthäcksler realisiert. Das Myzel überlebt den Zerteilungsvorgang. Ausgehend von den einzelnen Fragmenten wird das Myzel anschließend weiterwachsen und sich erneut verbinden.

<img title="Myzel zerkleinern" src="res/assets/media/img/material_fragmentation_1.webp" width="50%">

Vor Inbetriebnahme des Gerätes gilt es, Nitril-Einmalhandschuhe, Mund-Nasenschutz sowie Schutzbrille anzulegen und sich mit dem Gebrauch des Gerätes vertraut zu machen. Bitte Sicherheitshinweise des Herstellers beachten.

Nun werden alle Oberflächen, welche mit Myzel in Kontakt kommen, gründlich gereinigt und anschließend mit 70% Alkohollösung desinfiziert.

Danach sollte zügig mit der Zerkleinerung begonnen werden. Hierzu werden die vorkultivierten Beutel geöffnet und stückweise in den Häcksler gegeben. Unter dem Auslass wird ein ebenfalls desinfiziertes, verschließbares Auffangbehältnis platziert.

Um ein Umherfliegen der Fragmente zu vermeiden, wird zwischen der Auffangbox und dem Auslass eine Plastiktüte gespannt.

Nachdem 2 Beutel zerkleinert wurden, wird die Box von außen desinfiziert und auf die Arbeitsfläche des Laminarströmungsabzugs gelegt und die entsprechende Form befüllt.

<img title="zerkleinertes Myzel" src="res/assets/media/img/material_fragmentation_2.webp" width="50%">

---
## 5. Absorberherstellung

Das hergestellte Substrat kann nun für beliebige Anwendungen genutzt werden. Im folgenden wird die Herstellung von Akustikabsorbern beschrieben.

### 5.1. Befüllung der Form

Das fragmentierte Material wird unter dem Laminarströmungsabzug unter aseptischen Bedingungen weiterverarbeitet.

Dort liegen die bereits [vorbereiteten Wachstumsformen](../mould/README.md#vorbereitung), 4 [Holzanker](../anchor/README.md) und die Ausrichtungsschablone.

<img title="Ausrichtungsschablone" src="res/assets/media/img/anchor_align_tool.webp" width="50%">

Die Form wird nach gründlichem Desinfizieren mit dem zerkleinerten Myzel befüllt. Die desinfizierten Holzanker werden dabei eingebettet.

<img title="Einsetzen der Ausrichtungsschablone" src="res/assets/media/img/anchor_align_tool_set.webp" width="50%">

<img title="Ankerposition" src="res/assets/media/img/anchor_align.webp" width="50%">

<img title="Einbetten des Ankers" src="res/assets/media/img/embed_anchor.webp" width="50%">

Das Myzel wird bis zum Kragen aufgefüllt (entpsricht 2.300 g Myzel). Anschließend wird die Andrückplatte aufgelegt. Diese wird mit Hilfe von Abstandshaltern über das Anbringen des Deckels auf eine definierte Höhe heruntergedrückt und komprimiert das Myzel flächig.

<img title="Andrückplatte" src="res/assets/media/img/pressure_plate_raw.webp" width="50%">

Die Andrückplatte wurde mittels eines Lasercutters ausgeschnitten. Die Quelldatei mit dem Schneidepfad liegt als .svg vor und lässt sich unter [/src/mech](./src/mech/lasercut_pressure_plate.svg) finden.

<img title="Andrückplatte" src="res/assets/media/img/pressure_plate.webp" width="50%">

Nachdem die Andrückplatte wieder entfernt wurde, wird der Deckel erneut angebracht und mit Kreppband versiegelt. Beim Durchführen der Anker durch die quadratischen Aussparungen im Deckel ist besonders Acht zu geben, dass sich die korrekte Lage der Anker nicht verändert.

<img title="Schließen der Wachstumsform" src="res/assets/media/img/mould_lid_assambly.webp" width="50%">

Zum Schluss werden die 35 mm Belüftungslöcher im Deckel mit 50 mm Micropore Tape abgeklebt. Hierdurch ist ein passiver Gasaustausch möglich, jedoch ohne, dass Staub oder Kontaminationen in die Wachstumsform gelangen.

<img title="geschlossene  Wachstumsform" src="res/assets/media/img/mould_lid.webp" width="50%">

### 5.2. Formdurchwachsung

<img title="Formdurchwachsung" src="res/assets/media/img/incubate.webp" width="50%">

Nachdem die Wachstumsform befüllt ist, wird sie bei 24 °C und Dunkelheit für weitere 2 - 4 Tage durchwachsen. Während dieser Zeit erholen sich die Pilzfäden (Hyphen) vom Schock der Zerkleinerung und gehen wieder in vegetatives Wachstum über. Durch das Zerstören der bisher entstandenen Hyphenverbindungen werden sie außerdem zu stärkerer Verzweigung angeregt.

Finden sich zwei Hyphen derselben Art, können sie sich vereinigen. Durch Ineinanderwachsen und Quervernetzen der mikroskopisch feinen Hyphen entsteht ein zusammenhängendes dreidimensionales Netz. 

Die Holzanker bestehen aus Buchenholz. Der glänzende Lackporling ist in der Lage, in  den Holzanker hineinzuwachsen und somit das Material mit dem Anker zu verbinden.

### 5.3. Anlockern

Sobald die zerkleinerten Myzelstücke wieder eine Einheit gebildet haben, wird die gesamte Wachstumsform gewendet. Die Wände der Box werden hierzu vorsichtig von der Myzeloberfläche gelöst. 

<img title="Lockern der Wachstumsform" src="res/assets/media/img/mould_loosen.webp" width="50%">

Nun kann das Myzel umgedreht werden. Es liegt nun mit der Rückseite auf dem Deckel auf und die Holzanker schauen nach unten heraus. Im Anschluss kann die Negativform entfernt werden. Die Aufbewahrungsbox wird erneut aufgesetzt, um ein Austrocknen des Myzels zu verhindern.

<img title="Entfernen der Box" src="res/assets/media/img/mould_remove_shell.webp" width="50%">
<img title="Entfernen der Negativform" src="res/assets/media/img/mould_remove_negative.webp" width="50%">
<img title="Myzeloberfläche" src="res/assets/media/img/mould_absent.webp" width="50%">
<img title="Wachstumsatmosphäre für Luftmyzel" src="res/assets/media/img/mould_aerial_mycelium.webp" width="50%">

> Über den gesamten Verlauf ist besonders darauf Acht zu geben, das Mzel nicht zu beschädigen. Im Zustand vor der Trocknung ist es sehr empfindlich.

Die gedrehten Paneele werden in dem wenige Zentimeter breiten Spalt zwischen Myzeloberfläche und Wachstumsform sogenanntes Luftmyzel bilden - eine Schicht, die sich bis zu 1 cm stark auflagert. Die Oberfläche sieht am Ende dieses Prozesses wattig aus und erinnert an die Oberfläche eines Camembert. Dieses Luftmyzel erzeugt nach dem Trocknungsprozess eine ansprechende Optik und eine angenehm weiche Haptik.

### 5.4. Entformen

Nach der Lockerung und einer weiteren 2 - 4 Tage langen Wachstumsphase kann das Paneel nun komplett aus der Wachstumsform herausgenommen und in den Trockner gegeben werden.

### 5.5. Trocknung

Im Trockner wird das Myzel zunächst auf für 48 Stunden bei 55°C getrocknet, bis sämtliche Restfeuchtigkeit aus dem Myzel entwichen ist. Anschließend wird es bei 70°C für 2 Stunden erhitzt, um den Organismus zu inaktivieren.

<img title="Trocknen der Prototypen" src="res/assets/media/img/dry.webp" width="50%">

Danach ist der Prototyp bereit um am [Befestigungssystem](../mounting_system/README.md) angebracht zu werden.

---
## 6. Sicherheitshinweise

Bei der Benutzung von Hochdruckbehältern, welche auf bis zu 121 °C aufgeheizt werden, ist auf besondere Sorgfalt zu achten. Zusdem sind alle vom Hersteller angegebenen Sicherheitsbestimmungen einzuhalten. Der Betrieb ist nur nach erfolgter Sicherheitseinweisung und mit Schutzausrüstung zulässig.

Zur Schutzbekleidung gehören:
- festes Schuhwerk
- Schutzbrille
- Sicherheitshandschuhe

---
## 7. Lizenz

CC_BY_SA_4.0